#include "stm32f10x.h"
#include <stdio.h>
#include "wiz_platform.h"
#include "wizchip_conf.h"
#include "wiz_interface.h"
#include "do_dns.h"
#include "sntp.h"

/*wizchip->STM32 Hardware Pin define*/
//	wizchip_SCS    --->     STM32_GPIOD7
//	wizchip_SCLK	 --->     STM32_GPIOB13
//  wizchip_MISO	 --->     STM32_GPIOB14
//	wizchip_MOSI	 --->     STM32_GPIOB15
//	wizchip_RESET	 --->     STM32_GPIOD8
//	wizchip_INT    --->     STM32_GPIOD9

/* The current routine uses a 12Mhz external crystal. If you use other crystals, you need to modify the system clock.
******************************************************************************
* stm32f10x.h			Modify 118 lines of external crystal frequency
* system_stm32f10x.c	Modify 1055 lines of frequency doubling factor
#endif
******************************************************************************
*/

#define SOCKET_ID 0
#define ETHERNET_BUF_MAX_SIZE (1024 * 2)

/* network information */
wiz_NetInfo default_net_info = {
    .mac = {0x00, 0x08, 0xdc, 0x12, 0x22, 0x12},
    .ip = {192, 168, 1, 30},
    .gw = {192, 168, 1, 1},
    .sn = {255, 255, 255, 0},
    .dns = {8, 8, 8, 8},
    .dhcp = NETINFO_DHCP};
uint8_t ethernet_buf[ETHERNET_BUF_MAX_SIZE] = {0};
uint8_t sntp_server_name[] = "cn.pool.ntp.org";
uint8_t sntp_server_ip[4] = {0};
uint8_t timezone = 39; // china
datetime date = {0};

int main(void)
{
    delay_init();
    debug_usart_init();
    wiz_timer_init();
    wiz_spi_init();
    wiz_rst_int_init();
    printf("%s SNTP example\r\n", _WIZCHIP_ID_);

    /* wizchip init */
    wizchip_initialize();

    network_init(ethernet_buf, &default_net_info);

    if (do_dns(ethernet_buf, sntp_server_name, sntp_server_ip))
    {
        printf("DNS request failed.\r\n");
        while (1)
        {
        }
    }

    SNTP_init(SOCKET_ID, sntp_server_ip, timezone, ethernet_buf);

    while (1)
    {
        if (SNTP_run(&date))
        {
            printf("Beijing time now: %04d-%02d-%02d  %02d:%02d:%02d\r\n", date.yy, date.mo, date.dd, date.hh, date.mm, date.ss);
            break;
        }
    }
}
